package eu.flygare.utbildning.reactive;

import java.io.InputStream;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import org.eclipse.microprofile.rest.client.inject.RestClient;

@Path("/hello")
public class RestResource {

    @RestClient
    SampleRestClient restclient;

    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String hello() {
        return "Hello RESTEasy";
    }

    @Path("/sample")
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public RestEntity getSample() {
        RestEntity res = new RestEntity();
        res.id = "Fooo";
        restclient.getSample().subscribe().with(theItem -> {
            System.out.println("Got item: " + theItem);
        }, failure -> {
            System.out.println("Failure");
        });
        return res;
    }

    @Path("/response")
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public RestEntity getResponse() {
        RestEntity res = new RestEntity();
        res.id = "Fooo";
        restclient.getResponse().subscribe().with(response -> {
            if (response.getStatus() / 100 == 2) {
                // Got 200 series status, there should be data

                Object entity = response.getEntity();
                if (entity == null) {
                    System.out.println("response.getEntity() returned null, getting body using readEntity");
                    String jsondata = response.readEntity(String.class);
                    List<RestEntity> mapdata = RestUtility.jsonb.fromJson(jsondata, new LinkedList<Map<String, ? extends Object>>().getClass());
                    System.out.println("Result have " + mapdata.size() + " elements");
                } else {
                    System.out.println("Response have an entity");
                    List<Map<String, Object>> mapdata = RestUtility.jsonb.fromJson((InputStream) (entity), new LinkedList<Map<String, ? extends Object>>().getClass());
                    System.out.println("Result have " + mapdata.size() + " elements");
                }
               
            }
        }, failure -> {
            System.out.println("Failure");
        });
        return res;
    }

}
